--Utilizando comentarios por bloque, en lnea, y en lnea sobre programa.
/* Comentarios.sql
Programa para la comprobacin del uso de comentarios
Autor: Jos Felipe Ramrez
Fecha: 01/01/2005
*/
Select
	* -- Todos los campos
From
	authors  -- Autores de libros
--Fin del programa

------------------------------------------------------------------------------------

--Utilizando PRINT para generar resultados hacia el cliente SQL.
PRINT @Fecha = Hoy es    +
CONVERT(varchar(11), GETDATE(), 100)

------------------------------------------------------------------------------------

--Declarando una variable e imprimiendo el valor que se le ha asignado.
DECLARE @ao integer
SET @ao = 1994
PRINT @ao

------------------------------------------------------------------------------------

--Declaracin, asignacin de valor, y uso de una variable en un script que mostrar el resumen 
--de cantidad de unidades vendidas por ttulo, en el ao que se especifique.
--Parametrizando una consulta mediante el uso de variables.
Use pubs
Declare @ao integer
Select @ao = 1994

Select 
	titles.title,
	sum(sales.qty)
From 
	sales,
	titles
Where
	sales.title_id = titles.title_id and
	datepart(yy,sales.ord_date) = @ao
Group by
	titles.title

------------------------------------------------------------------------------------

--Declaracin de una variable local, asignndole el producto de una consulta que retorna un solo valor 
--(consulta escalar de funcin agregada).
--En trminos generales, se busca aquellas ventas que estuvieron, en volumen, por encima del promedio.
Use pubs
Declare @promedio_volumen integer
Select @promedio_volumen = 
	(select avg(qty) from sales)
Print @promedio_volumen

Select 
	sales.ord_num,
	sales.qty
From 
	sales 
Where 
	sales.qty >= @promedio_volumen

------------------------------------------------------------------------------------

--Comprobacin de la existencia de las variables globales 
--(observe cmo la variable es utilizada, aunque usted no la declare en ningn lado).
Use pubs
Select * from authors
Print @@rowcount

------------------------------------------------------------------------------------

--Se deben obtener las ventas de un determinado ttulo; 
--a) si el ttulo ha sido vendido, se debe mostrar un mensaje que nos diga que el ttulo ha tenido 
--ventas, para posteriormente detallar todas las ventas correspondientes.
--b) En caso de que no se haya vendido el ttulo, debe aparecer un mensaje que diga que el ttulo no 
--se ha vendido, sugiriendo intentar con otro. 
Use pubs
Set nocount on
declare @ocurrencias integer
declare @ttulo char(10)
Select @ttulo = PC1035
Select @ocurrencias = 
	(select 
		count(*) 
	from 
		sales 
	where 
		sales.title_id = @ttulo)
If @ocurrencias > 0
	Begin
		Print Ventas encontradas
		Select
			sales.ord_num,
			sales.qty,
			sales.title_id
		From
			sales
		Where
			sales.title_id = @ttulo
	end
else
	begin
		print No se encontraron ocurrencias
		print Intente otro ttulo
	end

------------------------------------------------------------------------------------

--Las ventas tienen diferentes categoras: menores a 30 piezas, son consideradas pequeas, 
--de 30 a 50 son consideradas buenas, y de ms de 50, son consideradas excelentes.
--Despliegue las rdenes de venta, sealando de qu categora de venta se trata.
Use pubs
Select
	sales.ord_num,
	Categora = 
CASE
when sales.qty < 30 then pequeas
when sales.qty between 30 and 50 then buenas
	      else excelentes
END
From
	Sales

------------------------------------------------------------------------------------

--Consulta que determina la cantidad mxima vendida en una sola orden.
--Despus muestra cuntas rdenes se vendieron por cada una de las posibles cantidades de venta, 
--mientras que no se sobrepase el nmero mximo, pues ya no tendra caso.
Declare @maximo integer
set @maximo = (select max(qty) from sales)

print 'Mxima cantidad vendida:' + str(@maximo)
print 'Ordenes por cantidad vendida------------------'

declare @contador integer
declare @ordenes integer
set @contador = 1
while @contador <= @maximo

Begin
	set @ordenes = (select count(*) from sales 
		where qty=@contador)
	print 'Ordenes que se vendieron ' + 
		str(@contador) + ':' +
		str(@ordenes) 
	set @contador = @contador + 1
End

------------------------------------------------------------------------------------

--Elabore el ejercicio anterior de una manera ms elaborada.   Agregue comentarios.
--Antes de investigar las ventas del ttulo, investigue si el ttulo mismo existe 
--(si no existe cmo analizamos sus ventas?). Controle el flujo del programa utilizando un GOTO.
--Pruebe el programa asignando a la variable @ttulo los valores PC1035 (que s existe) y PC0000 (que no existe).
/* Anlisis de ventas
Permite analizar las ventas que se han tenido de un determinado ttulo.
*/
Use pubs
-- Se anula la salida automtica de SQL Server
set nocount on

-- Declaracin de variables
declare @ocurrencias integer
declare @ttulo char(10)
declare @mensaje char(100)
-- Ttulo a buscar
select @ttulo = PC1035
-- Revisando el nmero de ttulos con esa clave
select @ocurrencias = (	select 
		count(*) 
		from 
			titles 
		where 
			titles.title_id = @ttulo)
-- Si el ttulo con esa clave no existe, 
-- se reporta la inexistencia y va a FIN
-- Si existe, se muestra el ttulo y contina

if @ocurrencias = 0
	begin
		select El tlulo  + @ttulo + no existe.
		print @mensaje
		goto FIN
	end
else
	begin
		select @mensaje = Ttulo: + (select 
 				titles.title 
				from titles where 
				titles.title_id = @ttulo)
		print @mensaje
	end

-- Evala cuantas ventas hay del ttulo

select @ocurrencias = 
	(select 
		count(*) 
	from 
		sales 
	where 
		sales.title_id = @ttulo)
-- Si hay ms de una venta, muestra las ventas.
-- De lo contrario, sugiere el uso de otra clave

if @ocurrencias > 0
	begin
		print Se encontraron ventas del ttulo
		select
			sales.ord_num,
			sales.qty,
			sales.title_id
		from
			sales
		where
			sales.title_id = @ttulo
	end
else
	begin
		print No se encontraron ocurrencias
		print Intente otro ttulo
	end

FIN:





















